@@ -5,7 +5,7 @@ use warnings;
 
 use Carp;    # Removing carp will break the XS code.
 
-our $VERSION = '0.29_02';
+our $VERSION = '0.29_03';
 
 our $AUTOLOAD;
 use AutoLoader 'AUTOLOAD';
@@ -49,7 +49,7 @@ Crypt::OpenSSL::RSA - RSA encoding and decoding, using the openSSL libraries
   print "public key (in X509 format) is:\n",
         $rsa->get_public_key_x509_string();
 
-  $rsa_priv->use_md5_hash(); # use_sha1_hash is the default
+  $rsa_priv->use_md5_hash(); # insecure. use_sha256_hash or use_sha1_hash are the default
   $signature = $rsa_priv->sign($plaintext);
   print "Signed correctly\n" if ($rsa->verify($plaintext, $signature));
 
@@ -106,16 +106,16 @@ Create a new C<Crypt::OpenSSL::RSA> object by constructing a
 private/public key pair.  The first (mandatory) argument is the key
 size, while the second optional argument specifies the public exponent
 (the default public exponent is 65537).  The padding is set to
-PKCS1_OAEP, but can be changed with C<use_xxx_padding> methods.
+C<PKCS1_OAEP>, but can be changed with use_xxx_padding methods.
 
 =item new_key_from_parameters
 
-Given C<Crypt::OpenSSL::Bignum> objects for C<n>, C<e>, and optionally C<d>,
-C<p>, and C<q>, where C<p> and C<q> are the prime factors of C<n>, C<e> is
-the public exponent and C<d> is the private exponent, create a new
-C<Crypt::OpenSSL::RSA> object using these values.  If C<p> and C<q> are
-provided and C<d> is C<undef>, C<d> is computed.  Note that while C<p> and
-C<q> are not necessary for a private key, their presence will speed up
+Given L<Crypt::OpenSSL::Bignum> objects for n, e, and optionally d, p,
+and q, where p and q are the prime factors of n, e is the public
+exponent and d is the private exponent, create a new
+Crypt::OpenSSL::RSA object using these values.  If p and q are
+provided and d is undef, d is computed.  Note that while p and q are
+not necessary for a private key, their presence will speed up
 computation.
 
 =cut
@@ -126,7 +126,7 @@ sub new_key_from_parameters {
 
 =item import_random_seed
 
-Import a random seed from C<Crypt::OpenSSL::Random>, since the OpenSSL
+Import a random seed from L<Crypt::OpenSSL::Random>, since the OpenSSL
 libraries won't allow sharing of random structures across perl XS
 modules.
 
@@ -215,14 +215,14 @@ of padding.
 
 =item use_pkcs1_oaep_padding
 
-Use EME-OAEP padding as defined in PKCS #1 v2.0 with SHA-1, MGF1 and
+Use C<EME-OAEP> padding as defined in PKCS #1 v2.0 with SHA-1, MGF1 and
 an empty encoding parameter. This mode of padding is recommended for
 all new applications.  It is the default mode used by
 C<Crypt::OpenSSL::RSA>.
 
 =item use_sslv23_padding
 
-Use PKCS #1 v1.5 padding with an SSL-specific modification that
+Use C<PKCS #1 v1.5> padding with an SSL-specific modification that
 denotes that the server is SSL3 capable.
 
 =item use_md5_hash
@@ -230,21 +230,31 @@ denotes that the server is SSL3 capable.
 Use the RFC 1321 MD5 hashing algorithm by Ron Rivest when signing and
 verifying messages.
 
+Note that this is considered B<insecure>.
+
 =item use_sha1_hash
 
 Use the RFC 3174 Secure Hashing Algorithm (FIPS 180-1) when signing
-and verifying messages. This is the default.
+and verifying messages. This is the default, when use_sha256_hash is
+not available.
 
 =item use_sha224_hash, use_sha256_hash, use_sha384_hash, use_sha512_hash
 
 These FIPS 180-2 hash algorithms, for use when signing and verifying
 messages, are only available with newer openssl versions (>= 0.9.8).
 
+use_sha256_hash is the default hash mode when available.
+
 =item use_ripemd160_hash
 
 Dobbertin, Bosselaers and Preneel's RIPEMD hashing algorithm when
 signing and verifying messages.
 
+=item use_whirlpool_hash
+
+Vincent Rijmen und Paulo S. L. M. Barreto ISO/IEC 10118-3:2004
+WHIRLPOOL hashing algorithm when signing and verifying messages.
+
 =item size
 
 Returns the size, in bytes, of the key.  All encrypted text will be of
